@@ -7,19 +7,28 @@
 #' @return Object of \code{\link{R6Class}} for modelling an ISO SpatialTemporalExtent
 #' @format \code{\link{R6Class}} object.
 #'
+#' @field spatialExtent [\code{\link{ISOGeographicExtent}}] the geographic extent(s)
+#'
+#' @section Methods inherited from \code{\link{ISOTemporalExtent}}:
+#' \describe{
+#'  \item{\code{setTimeInstant(timeInstant)}}{
+#'    Sets a time instant, object of class \code{\link{GMLTimeInstant}}
+#'  }
+#'  \item{\code{setTimePeriod(timePeriod)}}{
+#'    Sets a time period, object of class \code{\link{GMLTimePeriod}}
+#'  }
+#' }
+#'
 #' @section Methods:
 #' \describe{
 #'  \item{\code{new(xml)}}{
-#'    This method is used to instantiate an ISOTemporalExtent
+#'    This method is used to instantiate an \code{\link{ISOSpatialTemporalExtent}}
 #'  }
 #'  \item{\code{addSpatialExtent(spatialExtent)}}{
-#'    Adds an object of class \code{ISOGeographicExtent}
-#'  }
-#'  \item{\code{setSpatialExtent(spatialExtent)}}{
-#'    Sets an object of class \code{ISOGeographicExtent}
+#'    Adds an object of class \code{\link{ISOGeographicExtent}}
 #'  }
 #'  \item{\code{delSpatialExtent(spatialExtent)}}{
-#'    Deletes an object of class \code{ISOGeographicExtent}
+#'    Deletes an object of class \code{\link{ISOGeographicExtent}}
 #'  }
 #' }
 #' 
@@ -31,7 +40,7 @@
 #'   tp <- GMLTimePeriod$new(beginPosition = start, endPosition = end)
 #'   md$setTimePeriod(tp)
 #'   spatialExtent <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
-#'   md$setSpatialExtent(spatialExtent)
+#'   md$addSpatialExtent(spatialExtent)
 #'   
 #'   xml <- md$encode()
 #'   
@@ -61,12 +70,6 @@ ISOSpatialTemporalExtent <- R6Class("ISOSpatialTemporalExtent",
        return(self$addListElement("spatialExtent", spatialExtent))
      },
      
-     #setSpatialExtent
-     setSpatialExtent = function(spatialExtent){
-       self$spatialExtent = list();
-       return(self$addSpatialExtent(spatialExtent))
-     },
-     
      #delSpatialExtent
      delSpatialExtent = function(spatialExtent){
        if(!is(spatialExtent,"ISOGeographicExtent")){
