@@ -15,22 +15,19 @@ md <- ISOMetadata$new(xml = xml)
 
 test_that("inspire - metadata validator",{
   testthat::skip_on_cran()
-  testthat::skip_on_travis()
   
   inspireValidator <- INSPIREMetadataValidator$new()
   inspireReport <- inspireValidator$getValidationReport(obj = md, raw = TRUE)
   expect_is(inspireReport, "list")
-  expect_equal(names(inspireReport), c("url","creationDate","lastUpdateDate","validity", "raw"))
+  expect_equal(names(inspireReport), c("Status","Completeness","Test Run ID","Log", "Ref URI", "HTML Report", "raw"))
 })
 
 test_that("inspire - metadata validator 'encode' shortcut",{
   testthat::skip_on_cran()
-  testthat::skip_on_travis()
   xml <- md$encode(inspire = TRUE)
 })
 
 test_that("inspire - metadata validator 'save' shortcut",{
   testthat::skip_on_cran()
-  testthat::skip_on_travis()
   md$save("my-metadata.xml", inspire = TRUE)
 })
\ No newline at end of file
